// 21/01/2023 15:15:24
// LED_COBAK3.ino
// ArduinoBLE - Version: Latest
#include <ArduinoBLE.h>

/*
  LED

  This example creates a Bluetooth Low Energy peripheral with service that contains a
  characteristic to control an LED.

  The circuit:
  - Arduino MKR WiFi 1010, Arduino Uno WiFi Rev2 board, Arduino Nano 33 IoT,
    Arduino Nano 33 BLE, or Arduino Nano 33 BLE Sense board.

  You can use a generic Bluetooth Low Energy central app, like LightBlue (iOS and Android) or
  nRF Connect (Android), to interact with the services and characteristics
  created in this sketch.

  This example code is in the public domain.
*/

// Bluetooth Low Energy LED Service
BLEService ledService("019ed60S-0cfa-4ef3-ad3f-9395f3bdb110"); 

// Bluetooth Low Energy LED Switch Characteristic
BLEIntCharacteristic switchCharacteristic("019ed60C-0cfa-4ef3-ad3f-9395f3bdb111", BLERead | BLEWrite);

void setup() {
  Serial.begin(9600);
  while (!Serial);

  // set LED pin to output mode
  pinMode(LED_BUILTIN, OUTPUT);
  pinMode(5, OUTPUT);
  pinMode(6, OUTPUT);
  pinMode(7, OUTPUT);
  pinMode(8, OUTPUT);
  pinMode(9, OUTPUT);

  digitalWrite(LED_BUILTIN, LOW);  // when the central disconnects, turn off the LED
  digitalWrite(5, HIGH);           // turn LED1 off
  digitalWrite(6, HIGH);           // turn LED2 off
  digitalWrite(7, HIGH);           // turn LED3 off
  digitalWrite(8, HIGH);           // turn LED4 off
  digitalWrite(9, HIGH);           // turn LED5 off

  // begin initialization
  if (!BLE.begin()) {
    Serial.println("starting Bluetooth Low Energy module failed!");

    while (1);
  }

  // set advertised local name and service UUID:
  BLE.setLocalName("Nano_33_BLE");
  BLE.setAdvertisedService(ledService);

  // add the characteristic to the service
  ledService.addCharacteristic(switchCharacteristic);

  // add service
  BLE.addService(ledService);

  // set the initial value for the characeristic:
  switchCharacteristic.writeValue(0);

  // start advertising
  BLE.advertise();

  Serial.println("BLE LED Peripheral");
}

void loop() {
  // listen for Bluetooth Low Energy peripherals to connect:
  BLEDevice central = BLE.central();

  // if a central is connected to peripheral:
  if (central) {
    Serial.print("Connected to central: ");
    // print the central's MAC address:
    Serial.println(central.address());
    digitalWrite(LED_BUILTIN, HIGH);

    // while the central is still connected to peripheral:
    while (central.connected()) {

      // if the remote device wrote to the characteristic,
      // use the value to control the LED:

      if (switchCharacteristic.written()) {
        switch (switchCharacteristic.value()) {   // any value other than 0
          case 1:
            Serial.println("LED 1 on");
            digitalWrite(5, LOW);
            break;
          case 2:
            Serial.println("LED 2 on");
            digitalWrite(6, LOW);
            break;
          case 3:
            Serial.println("LED 3 on");
            digitalWrite(7, LOW);
            break;
          case 4:
            Serial.println("LED 4 on");
            digitalWrite(8, LOW);
            break;
          case 5:
            Serial.println("LED 5 on");
            digitalWrite(9, LOW);
            break;
          case 6:
            Serial.println("LED 1 off");
            digitalWrite(5, HIGH);
            break;
          case 7:
            Serial.println("LED 2 off");
            digitalWrite(6, HIGH);
            break;
          case 8:
            Serial.println("LED 3 off");
            digitalWrite(7, HIGH);
            break;
          case 9:
            Serial.println("LED 4 off");
            digitalWrite(8, HIGH);
            break;
          case 10:
            Serial.println("LED 5 off");
            digitalWrite(9, HIGH);
            break;
        }
      }
    }

    // when the central disconnects, print it out:                                                          
    Serial.print(F("Disconnected from central: "));
    Serial.println(central.address());
    digitalWrite(LED_BUILTIN, HIGH);  // when the central disconnects, turn off the LED
    digitalWrite(5, HIGH);
    digitalWrite(6, HIGH);
    digitalWrite(7, HIGH);
    digitalWrite(8, HIGH);
    digitalWrite(9, HIGH);
  }
}
